@@ -23,7 +23,7 @@ Usage::
     search_resources_paginator: SearchResourcesPaginator = client.get_paginator("search_resources")
     ```
 """
-from mypy_boto3_resource_groups.client import ResourceGroupsClient as Client, ResourceGroupsClient
+from mypy_boto3_resource_groups.client import ResourceGroupsClient, ResourceGroupsClient as Client
 from mypy_boto3_resource_groups.paginator import (
     ListGroupResourcesPaginator,
     ListGroupsPaginator,
